monazco game

Use run.py to play in the console
use monazco.monazcoEnv() to run the game as a gym-like environment

Please see board.jpg for a picture of what the board looks like, so you can understand the tests and stuff